@@ -3,7 +3,8 @@ import numpy as np
 
 __all__ = ['median', 'nanmedian', 'nansum', 'nanmean', 'nanvar', 'nanstd',
            'nanmin', 'nanmax', 'nanargmin', 'nanargmax', 'rankdata',
-           'nanrankdata', 'ss', 'partsort', 'argpartsort']
+           'nanrankdata', 'ss', 'nn', 'partsort', 'argpartsort', 'replace',
+           'anynan', 'allnan']
 
 def median(arr, axis=None):
     "Slow median function used for unaccelerated ndim/dtype combinations."
@@ -70,7 +71,7 @@ def nanstd(arr, axis=None, ddof=0):
         if axis < 0:
             axis += arr.ndim
         if (axis < 0) or (axis >= arr.ndim):
-            raise ValueError, "axis(=%d) out of bounds" % axis
+            raise ValueError("axis(=%d) out of bounds" % axis)
     else:
         # Older versions of scipy choke on axis=None
         arr = arr.ravel()
@@ -107,6 +108,7 @@ def nanargmax(arr, axis=None):
 
 def rankdata(arr, axis=None):
     "Slow rankdata function used for unaccelerated ndim/dtype combinations."
+    arr = np.asarray(arr)
     if axis is None:
         arr = arr.ravel()
         axis = 0
@@ -122,6 +124,7 @@ def rankdata(arr, axis=None):
 
 def nanrankdata(arr, axis=None):
     "Slow nanrankdata function used for unaccelerated ndim/dtype combinations."
+    arr = np.asarray(arr)
     if axis is None:
         arr = arr.ravel()
         axis = 0
@@ -143,6 +146,24 @@ def ss(arr, axis=0):
     "Slow sum of squares used for unaccelerated ndim/dtype combinations."
     return scipy_ss(arr, axis)
 
+def nn(arr, arr0, axis=1):
+    "Slow nearest neighbor used for unaccelerated ndim/dtype combinations."
+    arr = np.array(arr, copy=False)
+    arr0 = np.array(arr0, copy=False)
+    if arr.ndim != 2:
+        raise ValueError("`arr` must be 2d")
+    if arr0.ndim != 1:
+        raise ValueError("`arr0` must be 1d")
+    if axis == 1:
+        d = (arr - arr0) ** 2
+    elif axis == 0:
+        d = (arr - arr0.reshape(-1,1)) ** 2
+    else:
+        raise ValueError("`axis` must be 0 or 1.")
+    d = d.sum(axis)
+    idx = np.argmin(d)
+    return np.sqrt(d[idx]), idx    
+
 def partsort(arr, n, axis=-1):
     "Slow partial sort used for unaccelerated ndim/dtype combinations."
     return np.sort(arr, axis)
@@ -151,6 +172,32 @@ def argpartsort(arr, n, axis=-1):
     "Slow partial argsort used for unaccelerated ndim/dtype combinations."
     return np.argsort(arr, axis)
 
+def replace(arr, old, new):
+    "Slow replace (inplace) used for unaccelerated ndim/dtype combinations."
+    if type(arr) is not np.ndarray:
+        raise TypeError("`arr` must be a numpy array.")
+    if not issubclass(arr.dtype.type, np.inexact):
+        if old != old:
+            # int arrays do not contain NaN
+            return
+        if int(old) != old:
+            raise ValueError("Cannot safely cast `old` to int.")
+        if int(new) != new:
+            raise ValueError("Cannot safely cast `new` to int.")
+    if old != old:
+        mask = np.isnan(arr)
+    else:
+        mask = arr == old
+    np.putmask(arr, mask, new)
+
+def anynan(arr, axis=None):
+    "Slow check for Nans used for unaccelerated ndim/dtype combinations."
+    return np.isnan(arr).any(axis)
+
+def allnan(arr, axis=None):
+    "Slow check for all Nans used for unaccelerated ndim/dtype combinations."
+    return np.isnan(arr).all(axis)
+
 # ---------------------------------------------------------------------------
 #
 # SciPy
@@ -404,12 +451,12 @@ def scipy_rankdata(a):
     sumranks = 0
     dupcount = 0
     newarray = np.zeros(n, float)
-    for i in xrange(n):
+    for i in range(n):
         sumranks += i
         dupcount += 1
         if i==n-1 or svec[i] != svec[i+1]:
             averank = sumranks / float(dupcount) + 1
-            for j in xrange(i-dupcount+1,i+1):
+            for j in range(i-dupcount+1,i+1):
                 newarray[ivec[j]] = averank
             sumranks = 0
             dupcount = 0
