@@ -26,7 +26,7 @@ def move_sum(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -43,7 +43,7 @@ def move_sum(arr, window, axis=-1, method='filter'):
 
     Returns
     -------
-    y : ndarray
+    y : array_like
         The moving sum of the input array along the specified axis. The output
         has the same shape as the input.
 
@@ -54,6 +54,7 @@ def move_sum(arr, window, axis=-1, method='filter'):
        array([ NaN,   3.,   5.,   7.])
 
     """
+    arr = np.array(arr, copy=False)
     if method == 'filter':
         y = move_sum_filter(arr, window, axis=axis)
     elif method == 'strides':
@@ -62,7 +63,7 @@ def move_sum(arr, window, axis=-1, method='filter'):
         y = move_func_loop(np.sum, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -74,7 +75,7 @@ def move_nansum(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -96,12 +97,6 @@ def move_nansum(arr, window, axis=-1, method='filter'):
         NaNs. (A window with all NaNs returns NaN for the window sum.) The
         output has the same shape as the input.
         
-    Notes
-    -----
-    Care should be taken when using the `cumsum` moving window method. On
-    some problem sizes it is fast; however, it is possible to get small
-    negative values even if the input is non-negative.
-
     Examples
     --------
     >>> arr = np.array([1, 2, np.nan, 4])
@@ -109,6 +104,7 @@ def move_nansum(arr, window, axis=-1, method='filter'):
     array([ NaN,   3.,   2.,   4.])
 
     """
+    arr = np.array(arr, copy=False)
     if method == 'filter':
         y = move_nansum_filter(arr, window, axis=axis)
     elif method == 'strides':
@@ -117,7 +113,7 @@ def move_nansum(arr, window, axis=-1, method='filter'):
         y = move_func_loop(np.nansum, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'cumsum', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -129,7 +125,7 @@ def move_sum_filter(arr, window, axis=-1):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -155,6 +151,7 @@ def move_sum_filter(arr, window, axis=-1):
     array([ NaN,   3.,   5.,   7.])
 
     """
+    arr = np.array(arr, copy=False)
     global convolve1d
     if convolve1d is None:
         try:
@@ -162,11 +159,11 @@ def move_sum_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     w = np.ones(window, dtype=int)
     x0 = (1 - window) // 2
@@ -180,7 +177,7 @@ def move_nansum_filter(arr, window, axis=-1):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -207,6 +204,7 @@ def move_nansum_filter(arr, window, axis=-1):
     array([ NaN,   3.,   2.,   4.,   9.,  11.,  13.])
 
     """
+    arr = np.array(arr, copy=False)
     global convolve1d
     if convolve1d is None:
         try:
@@ -214,11 +212,11 @@ def move_nansum_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = 0
@@ -240,7 +238,7 @@ def move_mean(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -268,6 +266,7 @@ def move_mean(arr, window, axis=-1, method='filter'):
     array([ NaN,  1.5,  2.5,  3.5])
     
     """
+    arr = np.array(arr, copy=False)
     if method == 'filter':
         y = move_mean_filter(arr, window, axis=axis)
     elif method == 'strides':
@@ -276,7 +275,7 @@ def move_mean(arr, window, axis=-1, method='filter'):
         y = move_func_loop(np.mean, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -288,7 +287,7 @@ def move_nanmean(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -323,6 +322,7 @@ def move_nanmean(arr, window, axis=-1, method='filter'):
     array([ NaN,  1.5,  2. ,  4. ])
     
     """
+    arr = np.array(arr, copy=False)
     if method == 'filter':
         y = move_nanmean_filter(arr, window, axis=axis)
     elif method == 'strides':
@@ -331,7 +331,7 @@ def move_nanmean(arr, window, axis=-1, method='filter'):
         y = move_func_loop(bn.slow.nanmean, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'cumsum', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -339,6 +339,7 @@ def move_nanmean(arr, window, axis=-1, method='filter'):
 
 def move_mean_filter(arr, window, axis=-1):
     "Moving window mean implemented with a filter."
+    arr = np.array(arr, copy=False)
     global convolve1d
     if convolve1d is None:
         try:
@@ -346,11 +347,11 @@ def move_mean_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1: 
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     w = np.empty(window)
     w.fill(1.0 / window)
@@ -361,6 +362,7 @@ def move_mean_filter(arr, window, axis=-1):
 
 def move_nanmean_filter(arr, window, axis=-1):
     "Moving window nanmean implemented with a filter."
+    arr = np.array(arr, copy=False)
     global convolve1d
     if convolve1d is None:
         try:
@@ -368,11 +370,11 @@ def move_nanmean_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = 0
@@ -395,7 +397,7 @@ def move_var(arr, window, axis=-1, method='filter', ddof=0):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -423,6 +425,7 @@ def move_var(arr, window, axis=-1, method='filter', ddof=0):
     array([  NaN,  0.25,  0.25,  0.25])
     
     """
+    arr = np.array(arr, copy=False)
     if ddof != 0:
         raise ValueError("`ddof` must be zero for unaccelerated input.")
     if method == 'filter':
@@ -433,7 +436,7 @@ def move_var(arr, window, axis=-1, method='filter', ddof=0):
         y = move_func_loop(np.var, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -445,7 +448,7 @@ def move_nanvar(arr, window, axis=-1, method='filter', ddof=0):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -474,6 +477,7 @@ def move_nanvar(arr, window, axis=-1, method='filter', ddof=0):
     array([  NaN,   NaN,  0.25,  1.  ,  0.25])
     
     """
+    arr = np.array(arr, copy=False)
     if ddof != 0:
         raise ValueError("`ddof` must be zero for unaccelerated input.")
     if method == 'filter':
@@ -484,7 +488,7 @@ def move_nanvar(arr, window, axis=-1, method='filter', ddof=0):
         y = move_func_loop(bn.slow.nanvar, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -492,6 +496,7 @@ def move_nanvar(arr, window, axis=-1, method='filter', ddof=0):
 
 def move_var_filter(arr, window, axis=-1):
     "Moving window variance implemented with a filter."
+    arr = np.array(arr, copy=False)
     global convolve1d
     if convolve1d is None:
         try:
@@ -499,11 +504,11 @@ def move_var_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     w = np.empty(window)
     w.fill(1.0 / window)
@@ -518,6 +523,7 @@ def move_var_filter(arr, window, axis=-1):
 
 def move_nanvar_filter(arr, window, axis=-1):
     "Moving window variance ignoring NaNs, implemented with a filter."
+    arr = np.array(arr, copy=False)
     global convolve1d
     if convolve1d is None:
         try:
@@ -525,11 +531,11 @@ def move_nanvar_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = 0
@@ -557,7 +563,7 @@ def move_std(arr, window, axis=-1, method='filter', ddof=0):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -586,6 +592,7 @@ def move_std(arr, window, axis=-1, method='filter', ddof=0):
     array([ NaN,  0.5,  0.5,  0.5])
     
     """
+    arr = np.array(arr, copy=False)
     if ddof != 0:
         raise ValueError("`ddof` must be zero for unaccelerated input.")
     if method == 'filter':
@@ -596,7 +603,7 @@ def move_std(arr, window, axis=-1, method='filter', ddof=0):
         y = move_func_loop(np.std, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -608,7 +615,7 @@ def move_nanstd(arr, window, axis=-1, method='filter', ddof=0):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -638,6 +645,7 @@ def move_nanstd(arr, window, axis=-1, method='filter', ddof=0):
     array([ NaN,  NaN,  0.5,  1. ,  0.5])    
 
     """
+    arr = np.array(arr, copy=False)
     if ddof != 0:
         raise ValueError("`ddof` must be zero for unaccelerated input.")
     if method == 'filter':
@@ -648,7 +656,7 @@ def move_nanstd(arr, window, axis=-1, method='filter', ddof=0):
         y = move_func_loop(bn.slow.nanstd, arr, window, axis=axis)
     else:
         msg = "`method` must be 'filter', 'strides', or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -656,24 +664,26 @@ def move_nanstd(arr, window, axis=-1, method='filter', ddof=0):
 
 def move_std_filter(arr, window, axis=-1):
     "Moving window standard deviation implemented with a filter."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     y = move_var_filter(arr, window, axis=axis)
     np.sqrt(y, y)
     return y
 
 def move_nanstd_filter(arr, window, axis=-1):
     "Moving window standard deviation ignoring NaNs, implemented with a filter."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     y = move_nanvar_filter(arr, window, axis=axis)
     np.sqrt(y, y)
     return y
@@ -686,7 +696,7 @@ def move_min(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -721,7 +731,7 @@ def move_min(arr, window, axis=-1, method='filter'):
     elif method == 'loop':
         y = move_func_loop(np.min, arr, window, axis=axis)
     else:
-        raise ValueError, "`method` must be 'filter', 'strides', or 'loop'."
+        raise ValueError("`method` must be 'filter', 'strides', or 'loop'.")
     return y
 
 def move_nanmin(arr, window, axis=-1, method='filter'):
@@ -730,7 +740,7 @@ def move_nanmin(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -766,11 +776,12 @@ def move_nanmin(arr, window, axis=-1, method='filter'):
     elif method == 'loop':
         y = move_nanmin_loop(arr, window, axis=axis)
     else:
-        raise ValueError, "`method` must be 'filter', 'strides', or 'loop'."
+        raise ValueError("`method` must be 'filter', 'strides', or 'loop'.")
     return y
 
 def move_min_filter(arr, window, axis=-1):
     "Moving window minimium implemented with a filter."
+    arr = np.array(arr, copy=False)
     global minimum_filter1d
     if minimum_filter1d is None:
         try:
@@ -778,11 +789,11 @@ def move_min_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     y = arr.astype(float)
     x0 = (window - 1) // 2
     minimum_filter1d(y, window, axis=axis, mode='constant', cval=np.nan,
@@ -792,6 +803,7 @@ def move_min_filter(arr, window, axis=-1):
 def move_nanmin_filter(arr, window, axis=-1):
     "Moving window minimium ignoring NaNs, implemented with a filter."
     global minimum_filter1d, convolve1d
+    arr = np.array(arr, copy=False)
     if minimum_filter1d is None:
         try:
             from scipy.ndimage import minimum_filter1d
@@ -803,11 +815,11 @@ def move_nanmin_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = np.inf
@@ -824,12 +836,13 @@ def move_nanmin_filter(arr, window, axis=-1):
 
 def move_nanmin_loop(arr, window, axis=-1):
     "Moving window minimium ignoring NaNs, implemented with a python loop."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = np.inf
@@ -840,12 +853,13 @@ def move_nanmin_loop(arr, window, axis=-1):
 
 def move_nanmin_strides(arr, window, axis=-1):
     "Moving window minimium ignoring NaNs, implemented with stides tricks."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = np.inf
@@ -862,7 +876,7 @@ def move_max(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -897,7 +911,7 @@ def move_max(arr, window, axis=-1, method='filter'):
     elif method == 'loop':
         y = move_func_loop(np.max, arr, window, axis=axis)
     else:
-        raise ValueError, "`method` must be 'filter', 'strides', or 'loop'."
+        raise ValueError("`method` must be 'filter', 'strides', or 'loop'.")
     return y
 
 def move_nanmax(arr, window, axis=-1, method='filter'):
@@ -906,7 +920,7 @@ def move_nanmax(arr, window, axis=-1, method='filter'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -942,11 +956,12 @@ def move_nanmax(arr, window, axis=-1, method='filter'):
     elif method == 'loop':
         y = move_nanmax_loop(arr, window, axis=axis)
     else:
-        raise ValueError, "`method` must be 'filter', 'strides', or 'loop'."
+        raise ValueError("`method` must be 'filter', 'strides', or 'loop'.")
     return y
 
 def move_max_filter(arr, window, axis=-1):
     "Moving window maximium implemented with a filter."
+    arr = np.array(arr, copy=False)
     global maximum_filter1d
     if maximum_filter1d is None:
         try:
@@ -954,11 +969,11 @@ def move_max_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."  
+        raise ValueError("`window` is too long.")
     y = arr.astype(float)
     x0 = (window - 1) // 2
     maximum_filter1d(y, window, axis=axis, mode='constant', cval=np.nan,
@@ -967,6 +982,7 @@ def move_max_filter(arr, window, axis=-1):
 
 def move_nanmax_filter(arr, window, axis=-1):
     "Moving window maximium ignoring NaNs, implemented with a filter."
+    arr = np.array(arr, copy=False)
     global maximum_filter1d, convolve1d
     if maximum_filter1d is None:
         try:
@@ -979,11 +995,11 @@ def move_nanmax_filter(arr, window, axis=-1):
         except ImportError:
             raise ValueError("'filter' method requires SciPy.")
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = -np.inf
@@ -1000,12 +1016,13 @@ def move_nanmax_filter(arr, window, axis=-1):
 
 def move_nanmax_loop(arr, window, axis=-1):
     "Moving window maximium ignoring NaNs, implemented with a python loop."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = -np.inf
@@ -1016,12 +1033,13 @@ def move_nanmax_loop(arr, window, axis=-1):
 
 def move_nanmax_strides(arr, window, axis=-1):
     "Moving window maximium ignoring NaNs, implemented with stides tricks."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     arr = arr.astype(float)
     nrr = np.isnan(arr)
     arr[nrr] = -np.inf
@@ -1038,7 +1056,7 @@ def move_median(arr, window, axis=-1, method='loop'):
     
     Parameters
     ----------
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -1065,13 +1083,14 @@ def move_median(arr, window, axis=-1, method='loop'):
     array([ NaN,  1.5,  2.5,  3.5,  4.5])
 
     """
+    arr = np.array(arr, copy=False)
     if method == 'strides':
         y = move_func_strides(np.median, arr, window, axis=axis)
     elif method == 'loop':
         y = move_func_loop(np.median, arr, window, axis=axis)
     else:
         msg = "`method` must be 'strides' or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     if y.dtype != arr.dtype:
         if issubclass(arr.dtype.type, np.inexact):
             y = y.astype(arr.dtype)
@@ -1088,7 +1107,7 @@ def move_func(func, arr, window, axis=-1, method='loop', **kwargs):
     func : function
         A reducing function such as np.sum, np.max, or np.median that takes
         a Numpy array and axis and, optionally, key word arguments as input.
-    arr : ndarray
+    arr : array_like
         Input array.
     window : int
         The number of elements in the moving window.
@@ -1126,17 +1145,18 @@ def move_func(func, arr, window, axis=-1, method='loop', **kwargs):
         y = move_func_loop(func, arr, window, axis=axis)
     else:
         msg = "`method` must be 'strides' or 'loop'."
-        raise ValueError, msg
+        raise ValueError(msg)
     return y
 
 def move_func_loop(func, arr, window, axis=-1, **kwargs):
     "Generic moving window function implemented with a python loop."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     y = np.empty(arr.shape)
     y.fill(np.nan)
     idx1 = [slice(None)] * arr.ndim
@@ -1149,19 +1169,20 @@ def move_func_loop(func, arr, window, axis=-1, **kwargs):
 
 def move_func_strides(func, arr, window, axis=-1, **kwargs):
     "Generic moving window function implemented with strides."
+    arr = np.array(arr, copy=False)
     if axis == None:
-        raise ValueError, "An `axis` value of None is not supported."
+        raise ValueError("An `axis` value of None is not supported.")
     if window < 1:  
-        raise ValueError, "`window` must be at least 1."
+        raise ValueError("`window` must be at least 1.")
     if window > arr.shape[axis]:
-        raise ValueError, "`window` is too long."
+        raise ValueError("`window` is too long.")
     ndim = arr.ndim
     as_strided = np.lib.stride_tricks.as_strided
     idx = range(ndim)
     axis = idx[axis]
     arrshape0 = tuple(arr.shape)
     if axis >= ndim:
-        raise IndexError, "`axis` is out of range."
+        raise IndexError("`axis` is out of range.")
     if ndim == 1:
         strides = arr.strides
         shape = (arr.size - window + 1, window)
@@ -1189,7 +1210,7 @@ def move_func_strides(func, arr, window, axis=-1, **kwargs):
         if axis > 0:
             y = y.swapaxes(0, axis)
     else:
-        raise ValueError, "Only 1d, 2d, and 3d input arrays are supported."
+        raise ValueError("Only 1d, 2d, and 3d input arrays are supported.")
     ynan = np.empty(arrshape0)
     ynan.fill(np.nan)
     index = [slice(None)] * ndim 
