@@ -15,6 +15,7 @@ $ python func/setup.py build_ext --inplace
 """
 
 import os
+import os.path
 from distutils.core import setup
 from distutils.extension import Extension
 from Cython.Distutils import build_ext
@@ -28,7 +29,8 @@ elif np.int_ == np.int64:
 else:
     raise ValueError("Your OS does not appear to be 32 or 64 bits.")
 
-ext_modules = [Extension("func", ["func/%sbit/func.pyx" % bits],
+mod_dir = os.path.dirname(__file__)
+ext_modules = [Extension("func", [os.path.join(mod_dir, "%sbit/func.pyx") % bits],
                include_dirs=[np.get_include()])]
 
 setup(
@@ -37,5 +39,5 @@ setup(
   ext_modules = ext_modules
 )
 
-os.rename("func.so", "../func.so")
+os.rename("func.so", os.path.join(mod_dir, "../../func.so"))
 
