@@ -237,7 +237,7 @@ def nanargmax_selector(arr, axis):
 
     >>> func, a = bn.func.nanargmax_selector(arr, axis=0)
     >>> func
-    <built-in function nanargmax_1d_float64_axis0> 
+    <function nanargmax_1d_float64_axis0>
     
     Use the returned function and array to determine the maximum:
     
@@ -264,11 +264,11 @@ def nanargmax_selector(arr, axis):
         func = nanargmax_dict[key]
     except KeyError:
         if (axis < 0) or (axis >= ndim):
-            raise ValueError, "axis(=%d) out of bounds" % axis
+            raise ValueError("axis(=%d) out of bounds" % axis)
         try:
             func = nanargmax_slow_dict[axis]
         except KeyError:
             tup = (str(ndim), str(a.dtype), str(axis))
-            raise TypeError, "Unsupported ndim/dtype/axis (%s/%s/%s)." % tup
+            raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
 '''
