@@ -13,7 +13,7 @@ INT_DTYPES = [x for x in bn.dtypes if 'int' in x]
 loop = {}
 loop[1] = """\
     if (window < 1) or (window > nAXIS):
-        raise ValueError, MOVE_WINDOW_ERR_MSG % (window, nAXIS)
+        raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
 
     ring = <pairs*>stdlib.malloc(window * sizeof(pairs))
     end = ring + window
@@ -68,7 +68,7 @@ loop[1] = """\
 """        
 loop[2] = """\
     if (window < 1) or (window > nAXIS):
-        raise ValueError, MOVE_WINDOW_ERR_MSG % (window, nAXIS)
+        raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
 
     ring = <pairs*>stdlib.malloc(window * sizeof(pairs))
 
@@ -126,7 +126,7 @@ loop[2] = """\
 """
 loop[3] = """\
     if (window < 1) or (window > nAXIS):
-        raise ValueError, MOVE_WINDOW_ERR_MSG % (window, nAXIS)
+        raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
 
     ring = <pairs*>stdlib.malloc(window * sizeof(pairs))
 
@@ -197,7 +197,7 @@ floats['top'] = """
 def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a, int window):
     "Moving max of NDIMd array of dtype=DTYPE along axis=AXIS."
     cdef np.float64_t ai, aold
-    cdef int count
+    cdef Py_ssize_t count
     cdef pairs* ring
     cdef pairs* minpair
     cdef pairs* end
@@ -318,7 +318,7 @@ def move_max_selector(arr, int axis):
     >>> window, axis = 2, 0
     >>> func, a = bn.move.move_max_selector(arr, axis)
     >>> func
-    <built-in function move_max_1d_float64_axis0>    
+    <function move_max_1d_float64_axis0>
     
     Use the returned function and array to determine the moving maximum:
 
@@ -340,11 +340,11 @@ def move_max_selector(arr, int axis):
         func = move_max_dict[key]
     except KeyError:
         if (axis < 0) or (axis >= ndim):
-            raise ValueError, "axis(=%d) out of bounds" % axis
+            raise ValueError("axis(=%d) out of bounds" % axis)
         try:
             func = move_max_slow_dict[axis]
         except KeyError:
             tup = (str(ndim), str(a.dtype), str(axis))
-            raise TypeError, "Unsupported ndim/dtype/axis (%s/%s/%s)." % tup
+            raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
 '''   
