@@ -23,14 +23,14 @@ floats['top'] = """
 def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a,
                                   int window):
     "Moving mean of NDIMd array of dtype=DTYPE along axis=AXIS ignoring NaNs."
-    cdef int count = 0
+    cdef Py_ssize_t count = 0
     cdef double asum = 0, aold, ai
 """
 
 loop = {}
 loop[1] = """\
     if (window < 1) or (window > nINDEX0):
-        raise ValueError, MOVE_WINDOW_ERR_MSG % (window, nINDEX0)
+        raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nINDEX0))
 
     for iINDEX0 in range(window - 1):
         ai = a[INDEXALL]
@@ -65,7 +65,7 @@ loop[1] = """\
 """        
 loop[2] = """\
     if (window < 1) or (window > nAXIS):
-        raise ValueError, MOVE_WINDOW_ERR_MSG % (window, nAXIS)
+        raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
 
     for iINDEX0 in range(nINDEX0):
         asum = 0
@@ -103,7 +103,7 @@ loop[2] = """\
 """
 loop[3] = """\
     if (window < 1) or (window > nAXIS):
-        raise ValueError, MOVE_WINDOW_ERR_MSG % (window, nAXIS)
+        raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
 
     for iINDEX0 in range(nINDEX0):
         for iINDEX1 in range(nINDEX1):
@@ -242,7 +242,7 @@ def move_nanmean_selector(arr, int axis):
     >>> window, axis = 2, 0
     >>> func, a = bn.move.move_nanmean_selector(arr, axis)
     >>> func
-    <built-in function move_nanmean_1d_float64_axis0>    
+    <function move_nanmean_1d_float64_axis0>
     
     Use the returned function and array to determine the moving mean:
 
@@ -264,11 +264,11 @@ def move_nanmean_selector(arr, int axis):
         func = move_nanmean_dict[key]
     except KeyError:
         if (axis < 0) or (axis >= ndim):
-            raise ValueError, "axis(=%d) out of bounds" % axis    
+            raise ValueError("axis(=%d) out of bounds" % axis)
         try:
             func = move_nanmean_slow_dict[axis]
         except KeyError:
             tup = (str(ndim), str(a.dtype), str(axis))
-            raise TypeError, "Unsupported ndim/dtype/axis (%s/%s/%s)." % tup
+            raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
 '''   
