@@ -18,7 +18,7 @@ def arrayaxis(dtypes=bn.dtypes):
             if not issubclass(a.dtype.type, np.inexact):
                 for shape in shapes:
                     a = a.reshape(shape)
-                    for axis in range(-a.ndim, a.ndim) + [None]:
+                    for axis in list(range(-a.ndim, a.ndim)) + [None]:
                         yield a.copy(), axis
 
 def fast_checker(selector, mode='func'):
@@ -30,6 +30,8 @@ def fast_checker(selector, mode='func'):
                 func, a = selector(arr, axis)
             else:
                 func = np.sum
+        elif mode == 'replace':
+            func = selector(arr)
         else:
             raise ValueError("`mode` value not recognized.")
         if 'slow' in func.__name__:
@@ -97,6 +99,14 @@ def test_argpartsort_selector():
     "Test argpartsort_selector."
     fast_checker(bn.func.argpartsort_selector)
 
+def test_replace_selector():
+    "Test replace_selector."
+    fast_checker(bn.func.replace_selector, mode='replace')
+
+def test_anynan_selector():
+    "Test anynan_selector."
+    fast_checker(bn.func.anynan_selector)
+
 # Moving functions ----------------------------------------------------------
 
 def test_move_sum_selector():
